@@ -10,9 +10,11 @@ $metadata title
 
 import logging
 import re
+from ssl import OP_NO_TICKET
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
+from streamlink.session.http import SSLContextAdapter
 from streamlink.stream.hls import HLSStream
 from streamlink.stream.http import HTTPStream
 
@@ -20,6 +22,14 @@ from streamlink.stream.http import HTTPStream
 log = logging.getLogger(__name__)
 
 
+class DailymotionAdapter(SSLContextAdapter):
+    def get_ssl_context(self):
+        ctx = super().get_ssl_context()
+        ctx.options &= ~OP_NO_TICKET
+
+        return ctx
+
+
 @pluginmatcher(
     name="user",
     pattern=re.compile(r"https?://(?:\w+\.)?dailymotion\.com/(?P<user>(?!embed|video|live)[\w-]+)"),
@@ -36,6 +46,10 @@ class DailyMotion(Plugin):
     _URL_API_USER_VIDEO = "https://api.dailymotion.com/user/{user}/videos"
     _URL_STREAM_INFO = "https://www.dailymotion.com/player/metadata/video/{media_id}"
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.session.http.mount("https://", DailymotionAdapter())
+
     def _get_streams_from_media(self, media_id, params=None):
         media = self.session.http.get(
             self._URL_STREAM_INFO.format(media_id=media_id),
