@@ -114,7 +114,7 @@ class Streamlink:
         if follow_redirect:
             # Attempt to handle a redirect URL
             try:
-                res = self.http.head(url, allow_redirects=True, acceptable_status=[501])  # type: ignore[call-arg]
+                res = self.http.head(url, allow_redirects=True, acceptable_status=[501])
 
                 # Fall back to GET request if server doesn't handle HEAD.
                 if res.status_code == 501:
